@@ -92,7 +92,7 @@ sym_stream_encrypt (CDK_HD hd, CDK_STREAM inp, CDK_STREAM out)
     if (!hd || !inp || !out)
         return CDK_Inv_Value;
 
-    pw = _cdk_passphrase_get ("Enter Passphrase: ");
+    pw = _cdk_passphrase_get( hd, "Enter Passphrase: " );
     if( !pw )
         goto fail;
 
@@ -146,7 +146,7 @@ sym_stream_encrypt (CDK_HD hd, CDK_STREAM inp, CDK_STREAM out)
     rc = cdk_stream_kick_off( inp, out );
 
 fail:
-    _cdk_passphrase_free( pw );
+    _cdk_passphrase_free( pw, pw? strlen( pw ) : 0 );
     return rc;
 }
 
@@ -356,10 +356,10 @@ hash_data_file( char * file, int digest_algo, GCRY_MD_HD * r_md )
 
 
 static int
-handle_symkey_enc (CTX c, CDK_PACKET * pkt)
+handle_symkey_enc (CTX c, CDK_HD hd, CDK_PACKET * pkt)
 {
-    char * pw;
     cdkPKT_symkey_enc * key;
+    char * pw = NULL;
     int rc = 0;
 
     assert (pkt->pkttype == CDK_PKT_SYMKEY_ENC);
@@ -368,13 +368,13 @@ handle_symkey_enc (CTX c, CDK_PACKET * pkt)
     if (c->dek)
         return 0; /* we already decrypted the session key */
   
-    pw = _cdk_passphrase_get ("Enter Passphrase: ");
-    if (!pw)
+    pw = _cdk_passphrase_get( hd, "Enter Passphrase: " );
+    if( !pw )
         return CDK_Out_Of_Core;
 
     key = pkt->pkt.symkey_enc;
     rc = cdk_dek_from_passphrase( &c->dek, key->cipher_algo, key->s2k, 0, pw );
-    _cdk_passphrase_free (pw);
+    _cdk_passphrase_free( pw, pw? strlen( pw ) : 0 );
     return rc;
 }
 
@@ -424,7 +424,7 @@ handle_pubkey_enc( CTX c, CDK_HD hd, CDK_PACKET * pkt )
         return 0;
     rc = get_seckey( hd, hd->db.sec, enc->keyid, &sk );
     if( !rc )
-        rc = cdk_dek_extract( &c->dek, enc, sk );
+        rc = cdk_dek_extract( &c->dek, hd, enc, sk );
     if( !hd->cache.on )
         _cdk_free_seckey( sk );
     return rc;
@@ -432,7 +432,7 @@ handle_pubkey_enc( CTX c, CDK_HD hd, CDK_PACKET * pkt )
 
 
 static int
-rfc1991_get_sesskey (CDK_DEK * r_dek)
+rfc1991_get_sesskey (CDK_DEK * r_dek, CDK_HD hd)
 {
     CDK_S2K_HD s2k;
     char * pw;
@@ -441,23 +441,23 @@ rfc1991_get_sesskey (CDK_DEK * r_dek)
     if (!r_dek)
         return CDK_Inv_Value;
   
-    pw = _cdk_passphrase_get ("Enter Passphrase: ");
+    pw = _cdk_passphrase_get (hd, "Enter Passphrase: ");
     if (!pw)
         return CDK_Out_Of_Core;
     rc = cdk_s2k_new( &s2k, 0, GCRY_MD_MD5, NULL );
     if( rc ) {
-        _cdk_passphrase_free (pw);
+        _cdk_passphrase_free( pw, pw? strlen( pw ) : 0 );
         return CDK_Out_Of_Core;
     }
     rc = cdk_dek_from_passphrase( r_dek, GCRY_CIPHER_IDEA, s2k, 0, pw );
-    _cdk_passphrase_free( pw );
+    _cdk_passphrase_free( pw, pw? strlen( pw ) : 0 );
     cdk_free( s2k );
     return rc;
 }
 
   
 static int
-handle_encrypted (CTX c, CDK_PACKET * pkt, int use_mdc)
+handle_encrypted (CTX c, CDK_HD hd, CDK_PACKET * pkt, int use_mdc)
 {
     cdkPKT_encrypted * enc;
     int pgp2_compat = _cdk_is_idea_available ();
@@ -470,7 +470,7 @@ handle_encrypted (CTX c, CDK_PACKET * pkt, int use_mdc)
             return CDK_Error_No_Key;
         else if (!c->key_seen) {
             _cdk_log_debug ("RFC1991 message was detected.\n");
-            rc = rfc1991_get_sesskey (&c->dek);
+            rc = rfc1991_get_sesskey (&c->dek, hd);
             if (rc)
                 return rc;
         }
@@ -541,6 +541,7 @@ handle_plaintext( CTX c, CDK_PACKET * pkt, CDK_STREAM * ret_out )
         return CDK_Inv_Value;
 
     if( !c->tmpfp ) {
+        /* fixme: handle _CONSOLE */
         s = c->output? c->output : pkt->pkt.plaintext->name;
         rc = cdk_stream_create( s, ret_out );
         if( rc )
@@ -553,6 +554,7 @@ handle_plaintext( CTX c, CDK_PACKET * pkt, CDK_STREAM * ret_out )
     cdk_stream_seek( c->s, c->sig.present? c->sig.pt_offset : 0 );
     cdk_stream_set_literal_flag( c->s, 0, NULL );
     if( c->sig.present ) {
+        _cdk_log_debug( "enable hash filter (algo=%d)\n", c->sig.digest_algo );
         pfx = _cdk_stream_get_opaque( c->s, fPLAINTEXT );
         if( pfx )
             pfx->md = c->sig.md;
@@ -572,6 +574,8 @@ mpi_encode( cdkPKT_signature * sig )
     for( i = 0, len = 0; i < nsig; i++ )
         len += sig->mpi[i]->bytes + 2;
     p = cdk_calloc( 1, len + 1 );
+    if( !p )
+        return NULL;
     for( i = 0; i < nsig; i++ ) {
         a = sig->mpi[i];
         p[pos++] = a->bits >> 8;
@@ -607,14 +611,14 @@ handle_signature (CDK_HD hd, CTX c, CDK_PACKET * pkt)
     u32 keyid[2];
     int rc;
 
-    assert (pkt->pkttype == CDK_PKT_SIGNATURE);
+    assert( pkt->pkttype == CDK_PKT_SIGNATURE );
 
     if( !c->sig.present )
         return CDK_Inv_Packet;
 
-    _cdk_result_verify_free (hd->result.verify);
-    res = hd->result.verify = _cdk_result_verify_new ();
-    if (!hd->result.verify)
+    _cdk_result_verify_free( hd->result.verify );
+    res = hd->result.verify = _cdk_result_verify_new( );
+    if( !hd->result.verify )
         return CDK_Out_Of_Core;
   
     sig = pkt->pkt.signature;
@@ -625,7 +629,7 @@ handle_signature (CDK_HD hd, CTX c, CDK_PACKET * pkt)
         if( rc )
             return rc;
     }
-  
+
     cdk_sig_get_keyid( sig, keyid );
     set_verify_result( sig, res );
   
@@ -707,7 +711,7 @@ do_proc_packets( CDK_HD hd, CTX c, CDK_STREAM inp, CDK_STREAM * ret_out )
 
         switch (pkt->pkttype) {
         case CDK_PKT_SYMKEY_ENC:
-            rc = handle_symkey_enc (c, pkt);
+            rc = handle_symkey_enc (c, hd, pkt);
             _cdk_log_debug (" handle_symkey_enc (%d)\n", rc);
             break;
           
@@ -719,7 +723,7 @@ do_proc_packets( CDK_HD hd, CTX c, CDK_STREAM inp, CDK_STREAM * ret_out )
         case CDK_PKT_ENCRYPTED_MDC: 
         case CDK_PKT_ENCRYPTED:
             with_mdc = pkt->pkttype == CDK_PKT_ENCRYPTED_MDC;
-            rc = handle_encrypted (c, pkt, with_mdc);
+            rc = handle_encrypted (c, hd, pkt, with_mdc);
             _cdk_log_debug (" handle_encrypted (%d)\n", rc);
             if (!rc)
                 inp = c->s;
@@ -940,8 +944,9 @@ cdk_data_transform( CDK_HD hd, int mode,
 {
     CDK_STREAM inp, out;
     CDK_KEYDB_HD db;
+    CDK_KBNODE knode = NULL;
     size_t nlen;
-    int rc, nbytes = 0;
+    int rc, nbytes = 0, res[4];
     
     if( !hd )
         return CDK_Inv_Value;
@@ -988,6 +993,21 @@ cdk_data_transform( CDK_HD hd, int mode,
         rc = cdk_keydb_export( db, out, remusr );
         break;
 
+    case CDK_CRYPTYPE_IMPORT:
+        if( cdk_armor_filter_use( inp ) )
+            cdk_stream_set_armor_flag( inp, 0 );
+        rc = cdk_keydb_get_keyblock( inp, &knode );
+        if( knode ) {
+            db = cdk_handle_get_keydb( hd, CDK_DBTYPE_PK_KEYRING );
+            rc = cdk_keydb_import( db, knode, res );
+            if( !rc ) {
+                *outbuf = _cdk_keydb_get_importres_as_xml( res );
+                *outsize = strlen( *outbuf );
+            }
+            cdk_kbnode_release( knode );
+        }
+        break;
+
     default:
         rc = CDK_Inv_Mode;
         break;
@@ -1013,8 +1033,8 @@ cdk_data_transform( CDK_HD hd, int mode,
         }
     }
     else if( !rc && mode == CDK_CRYPTYPE_VERIFY ) {
-        *outbuf = cdk_sig_get_info_as_xml( hd, 0 );
-        *outsize = strlen( *outbuf );
+        *outbuf = cdk_sig_get_info_as_xml( hd, modval );
+        *outsize = *outbuf? strlen( *outbuf ) : 0;
     }
     cdk_stream_close( out );
     return rc;
