@@ -1462,6 +1462,28 @@ find_key_packet (CDK_KBNODE knode, int * r_secret)
 }
 
 
+char *
+_cdk_keydb_get_importres_as_xml( int result[4] )
+{
+    char * p;
+    const char * fmt;
+
+    fmt = "<OpenPGP-Import>\n"
+          "  <Public-Keys>\n"
+          "    <Read>%d</Read>\n"
+          "    <Updated>%d</Updated>\n"
+          "  </Public-Keys>\n"
+          "  <Secret-Keys>\n"
+          "    <Read>%d</Read>\n"
+          "    <Updated>%d</Updated>\n"
+          "  </Secret-Keys>\n"
+          "</OpenPGP-Import>\n";
+    p = cdk_calloc( 1, strlen( fmt ) + 128 );
+    sprintf( p, fmt, result[0], result[2], result[1], result[3] );
+    return p;
+}
+    
+
 int
 cdk_keydb_import (CDK_KEYDB_HD hd, CDK_KBNODE knode, int result[4])
 {
