@@ -55,6 +55,7 @@ struct cdk_keygen_s {
     unsigned protect:1;
     struct key_ctx_s key[2];
     char * pass;
+    size_t pass_len;
 };
 
 
@@ -254,16 +255,17 @@ cdk_keygen_set_passphrase( CDK_KEYGEN_CTX hd, const char * pass )
         return;
     if( pass ) {
         size_t n = strlen( pass );
-        cdk_free( hd->pass );
+        _cdk_sec_free( hd->pass, hd->pass_len );
         hd->pass = cdk_salloc( n + 1, 1 );
         if( hd->pass ) {
             memcpy( hd->pass, pass, n );
             hd->pass[n] = '\0';
+            hd->pass_len = n;
             hd->protect = 1;
         }
     }
 }
-      
+
 
 static int
 read_single_mpi( GCRY_SEXP s_key, const char * val, GCRY_MPI * r_resarr )
@@ -798,7 +800,7 @@ cdk_keygen_free( CDK_KEYGEN_CTX hd )
         cdk_free( hd->sym_prefs );
         cdk_free( hd->hash_prefs );
         cdk_free( hd->zip_prefs );
-        cdk_free( hd->pass );
+        _cdk_sec_free( hd->pass, hd->pass_len );
         _cdk_free_mpi_array( hd->key[0].n, hd->key[0].resarr );
         _cdk_free_mpi_array( hd->key[1].n, hd->key[1].resarr );
         cdk_free( hd );
