@@ -36,6 +36,11 @@
 #include "main.h"
 #include "packet.h"
 
+
+#define DEFAULT_CIPHER_ALGO GCRY_CIPHER_CAST5
+#define DEFAULT_DIGEST_ALGO GCRY_MD_SHA1
+
+
 static void *(*alloc_func) (size_t n) = gcry_xmalloc;
 static void *(*alloc_secure_func) (size_t n) = gcry_malloc_secure;
 static void *(*realloc_func) (void *p, size_t n) = gcry_realloc;
@@ -48,8 +53,6 @@ static CDK_LOG_FNC log_handler = NULL;
 static void *log_handler_value = NULL;
 static int log_level = CDK_LOG_NONE;
 
-static CDK_PASSPHRASE_CB passphrase_cb = NULL;
-
 
 /**
  * cdk_strerror:
@@ -238,6 +241,19 @@ cdk_free (void * ptr)
 }
 
 
+void
+_cdk_sec_free( void * ptr, size_t size )
+{
+    if( ptr ) {
+        memset( ptr, 0xff, size );
+        memset( ptr, 0xaa, size );
+        memset( ptr, 0x55, size );
+        memset( ptr, 0x00, size );
+        free_func( ptr );
+    }
+}
+
+
 static void
 _cdk_logv (int level, const char *fmt, va_list arg_ptr)
 {
@@ -316,14 +332,6 @@ _cdk_log_debug (const char *fmt, ...)
 }
 
 
-void
-cdk_passphrase_cb_set (CDK_PASSPHRASE_CB pass_fnc)
-{
-    if (pass_fnc)
-        passphrase_cb = pass_fnc;
-}
-
-
 #ifndef HAVE_PWD_H
 char *
 getpass (const char * prompt)
@@ -334,12 +342,12 @@ getpass (const char * prompt)
 
 
 char *
-_cdk_passphrase_get( const char * prompt )
+_cdk_passphrase_get( CDK_HD hd, const char * prompt )
 {
     char * p, * pass = NULL;
     
-    if( passphrase_cb )
-        return passphrase_cb( prompt );
+    if( hd->passphrase )
+        return hd->passphrase( hd->passphrase_value, prompt );
     p = getpass( prompt );
     if( p )
         pass = cdk_strdup( p );
@@ -348,9 +356,9 @@ _cdk_passphrase_get( const char * prompt )
 
 
 void
-_cdk_passphrase_free( char *pw )
+_cdk_passphrase_free( char *pw, size_t size )
 {
-    cdk_free( pw );
+    _cdk_sec_free( pw, size );
 }
 
 
@@ -371,7 +379,7 @@ handle_set_cipher (CDK_HD hd, int cipher)
     if( !hd )
         return;
     if (_cdk_cipher_test_algo (cipher))
-        cipher = GCRY_CIPHER_CAST5;
+        cipher = DEFAULT_CIPHER_ALGO;
     hd->cipher_algo = cipher;   
 }
 
@@ -382,25 +390,25 @@ handle_set_digest (CDK_HD hd, int digest)
     if( !hd )
         return;
     if( _cdk_md_test_algo( digest ) )
-        digest = GCRY_MD_SHA1;
+        digest = DEFAULT_DIGEST_ALGO;
     hd->digest_algo = digest;   
 }
 
 
 static void
-handle_set_s2k (CDK_HD hd, int mode, int digest, int cipher)
+handle_set_s2k( CDK_HD hd, int mode, int digest, int cipher )
 {
     if( !hd )
         return;
     if( _cdk_cipher_test_algo( cipher ) )
-        cipher = GCRY_CIPHER_CAST5;
+        cipher = DEFAULT_CIPHER_ALGO;
     if( _cdk_md_test_algo( digest ) )
-        digest = GCRY_MD_SHA1;
+        digest = DEFAULT_DIGEST_ALGO;
     if( mode < 0 || mode > 3 )
         mode = 3;
     hd->_s2k.mode = mode;
     hd->_s2k.digest_algo = digest;
-    hd->_s2k.cipher_algo = cipher;    
+    hd->_s2k.cipher_algo = cipher;
 }
 
 
@@ -416,8 +424,8 @@ handle_set_compat( CDK_HD hd, int val )
     hd->opt.rfc1991 = val == -1? 1: 0;
     hd->compress.algo = CDK_COMPRESS_ZIP;
     hd->compress.level = -1;
-    hd->cipher_algo = val == -1? GCRY_CIPHER_IDEA : GCRY_CIPHER_CAST5;
-    hd->digest_algo = val == -1? GCRY_MD_MD5: GCRY_MD_SHA1;
+    hd->cipher_algo = val == -1? GCRY_CIPHER_IDEA : DEFAULT_CIPHER_ALGO;
+    hd->digest_algo = val == -1? GCRY_MD_MD5: DEFAULT_DIGEST_ALGO;
     if( val == -1 )
         handle_set_s2k( hd, 0, hd->digest_algo, hd->cipher_algo );   
 }
@@ -447,7 +455,9 @@ cdk_handle_control( CDK_HD hd, int action, int cmd, ... )
 {
     va_list arg_ptr;
     int set = action == CDK_CTLF_SET, val = 0;
-    
+
+    if( !hd )
+        return -1;
     if( action != CDK_CTLF_SET && action != CDK_CTLF_GET )
         return -1;
     va_start( arg_ptr, cmd );
@@ -488,17 +498,22 @@ cdk_handle_control( CDK_HD hd, int action, int cmd, ... )
         break;
 
     case CDK_CTL_COMPRESS:
-        if( set )
-            handle_set_compress( hd, va_arg( arg_ptr, int ),
-                                 va_arg( arg_ptr, int ) );
+        if( set ) {
+            int algo = va_arg( arg_ptr, int );
+            int level = va_arg( arg_ptr, int );
+            handle_set_compress( hd, algo, level );
+        }
         else
             val = hd->compress.algo;
         break;
 
     case CDK_CTL_S2K:
-        if( set )
-            handle_set_s2k( hd, va_arg( arg_ptr, int ), va_arg( arg_ptr, int ),
-                            va_arg( arg_ptr, int ) );
+        if( set ) {
+            int mode = va_arg( arg_ptr, int );
+            int digest = va_arg( arg_ptr, int );
+            int cipher = va_arg( arg_ptr, int );
+            handle_set_s2k( hd, mode, digest, cipher );
+        }
         else
             val = hd->_s2k.mode;
         break;
@@ -514,6 +529,17 @@ cdk_handle_control( CDK_HD hd, int action, int cmd, ... )
         _cdk_free_seckey( hd->cache.sk );
         hd->cache.sk = NULL;
         break;
+
+    case CDK_CTL_FORCE_DIGEST:
+        if( set )
+            hd->opt.force_digest = va_arg( arg_ptr, int );
+        else
+            val = hd->opt.force_digest;
+        break;
+
+    default:
+        val = -1;
+        break;
     }
     va_end( arg_ptr );
     return val;
@@ -528,28 +554,28 @@ cdk_handle_control( CDK_HD hd, int action, int cmd, ... )
  * create a new session handle.
  **/
 int
-cdk_handle_new (CDK_HD * r_ctx)
+cdk_handle_new( CDK_HD * r_ctx )
 {
     CDK_HD c;
   
-    if (!r_ctx)
+    if( !r_ctx )
         return CDK_Inv_Value;
-  
-    c = cdk_calloc (1, sizeof *c);
-    if (!c)
+    
+    c = cdk_calloc( 1, sizeof *c );
+    if( !c )
         return CDK_Out_Of_Core;
     /* default */
     c->_s2k.mode = 3;
-    c->_s2k.digest_algo = GCRY_MD_SHA1;
-    c->_s2k.cipher_algo = GCRY_CIPHER_CAST5;
+    c->_s2k.digest_algo = DEFAULT_DIGEST_ALGO;
+    c->_s2k.cipher_algo = DEFAULT_CIPHER_ALGO;
 
     c->opt.mdc = 1;
     c->opt.compress = 1;
     c->opt.armor = 0;
     c->opt.textmode = 0;
 
-    c->digest_algo = GCRY_MD_SHA1;
-    c->cipher_algo = GCRY_CIPHER_CAST5;
+    c->digest_algo = DEFAULT_DIGEST_ALGO;
+    c->cipher_algo = DEFAULT_CIPHER_ALGO;
     c->compress.algo = CDK_COMPRESS_ZIP;
     c->compress.level = 6;
 
@@ -568,11 +594,11 @@ cdk_handle_new (CDK_HD * r_ctx)
  * secret keyring and the right handle is set.
  **/
 void
-cdk_handle_set_keydb (CDK_HD hd, CDK_KEYDB_HD db)
+cdk_handle_set_keydb( CDK_HD hd, CDK_KEYDB_HD db )
 {
     if( !hd )
         return;
-    if (db->secret)
+    if( db->secret )
         hd->db.sec = db;
     else
         hd->db.pub = db;
@@ -612,6 +638,25 @@ cdk_handle_set_callback (CDK_HD hd,
 }
 
 
+/**
+ * cdk_handle_set_passphrase_cb:
+ * @hd: session handle
+ * @cb: callback function
+ * @cb_value: the opaque value for the cb function
+ *
+ * set the passphrase callback.
+ **/
+void cdk_handle_set_passphrase_cb( CDK_HD hd,
+                                   char *(*cb) (void *opa, const char *prompt),
+                                   void * cb_value )
+{
+    if( !hd )
+        return;
+    hd->passphrase = cb;
+    hd->passphrase_value = cb_value;
+}
+
+
 /**
  * cdk_handle_free:
  * @hd: the handle
