@@ -23,7 +23,7 @@
 
 #include <stdarg.h>
 
-#define OPENCDK_VERSION "0.4.2"
+#define OPENCDK_VERSION "0.4.3"
 
 #ifdef __cplusplus
 extern "C" {
@@ -117,7 +117,8 @@ enum
   CDK_CTL_OVERWRITE     = 15,
   CDK_CTL_S2K           = 16,
   CDK_CTL_KEYCACHE_ON   = 17,
-  CDK_CTL_KEYCACHE_FREE = 18
+  CDK_CTL_KEYCACHE_FREE = 18,
+  CDK_CTL_FORCE_DIGEST  = 19
 };
 
 enum
@@ -152,6 +153,7 @@ enum
   CDK_MD_RMD160  = 3,
   CDK_MD_MD2     = 5,
   CDK_MD_TIGER   = 6,
+  CDK_MD_SHA256  = 8,
 };
 
 enum
@@ -217,6 +219,7 @@ enum
   CDK_CRYPTYPE_SIGN    = 3,
   CDK_CRYPTYPE_VERIFY  = 4,
   CDK_CRYPTYPE_EXPORT  = 5,
+  CDK_CRYPTYPE_IMPORT  = 6
 };
 
 enum
@@ -517,6 +520,9 @@ int cdk_handle_control( CDK_HD hd, int action, int cmd, ... );
 void cdk_handle_set_callback (CDK_HD hd,
                               void (*cb) (void *opa, int type, const char * s),
                               void * cb_value);
+void cdk_handle_set_passphrase_cb( CDK_HD hd,
+                                   char *(*cb) (void *opa, const char *prompt),
+                                   void * cb_value );
 
 /* shortcuts for some controls */
 #define cdk_handle_set_armor( a, val ) \
@@ -579,10 +585,8 @@ unsigned long cdk_pk_fingerprint_get_keyid (const unsigned char * fpr,
 unsigned long cdk_pk_get_keyid (cdkPKT_public_key * pk, unsigned long * keyid);
 unsigned long cdk_sk_get_keyid (cdkPKT_secret_key * sk, unsigned long * keyid);
 unsigned long cdk_sig_get_keyid (cdkPKT_signature * sg, unsigned long * keyid);
-typedef char * (*CDK_PASSPHRASE_CB) (const char *);
 int cdk_sk_unprotect (cdkPKT_secret_key * sk, const char * pw);
 int cdk_sk_protect (cdkPKT_secret_key * sk, const char * pw);
-void cdk_passphrase_cb_set (CDK_PASSPHRASE_CB pass_fnc);
 
 /*-- seskey.c --*/
 int cdk_sesskey_new( CDK_SESSKEY * r_sk );
@@ -595,7 +599,7 @@ int cdk_dek_from_passphrase( CDK_DEK * ret_dek, int cipher_algo,
                              CDK_S2K_HD s2k, int mode, const char * pw );
 int cdk_dek_encode_pkcs1( CDK_DEK dek, int nbits, CDK_SESSKEY * r_esk );
 int cdk_dek_decode_pkcs1( CDK_DEK * ret_dek, CDK_SESSKEY esk );
-int cdk_dek_extract( CDK_DEK * ret_dek, cdkPKT_pubkey_enc * enc,
+int cdk_dek_extract( CDK_DEK * ret_dek, CDK_HD hd, cdkPKT_pubkey_enc * enc,
                      cdkPKT_secret_key * sk );
 void cdk_dek_set_mdc_flag( CDK_DEK dek, int val );
 /* string to key */
@@ -687,12 +691,13 @@ int cdk_pklist_build (CDK_KEYDB_HD hd, CDK_STRLIST remusr,
 void cdk_pklist_release (CDK_KEYLIST pkl);
 int cdk_pklist_encrypt (CDK_KEYLIST pkl, CDK_DEK dek, CDK_STREAM out);
 /* secret key list */
-int cdk_sklist_build (CDK_KEYDB_HD hd, CDK_STRLIST locusr,
-                      CDK_KEYLIST * ret_skl, int unlock, unsigned int use);
+int cdk_sklist_build( CDK_KEYDB_HD db, CDK_HD hd, CDK_STRLIST locusr,
+                      CDK_KEYLIST * ret_skl, int unlock, unsigned int use );
 void cdk_sklist_release (CDK_KEYLIST skl);
 int cdk_sklist_write (CDK_KEYLIST skl, CDK_STREAM outp, void * mdctx,
                       int sigclass, int sigver);
-int cdk_sklist_write_onepass (CDK_KEYLIST skl, CDK_STREAM outp, int sigclass);
+int cdk_sklist_write_onepass( CDK_KEYLIST skl, CDK_STREAM outp,
+                              int sigclass, int mdalgo );
 
 /*-- encrypt.c --*/
 int cdk_stream_encrypt (CDK_HD hd, CDK_STRLIST remusr,
