@@ -105,29 +105,32 @@ read_16 (CDK_STREAM buf)
 
 
 static int
-read_s2k (CDK_STREAM inp, CDK_S2K_HD s2k)
+read_s2k( CDK_STREAM inp, CDK_S2K_HD s2k )
 {
     size_t nread = 0;
     int rc = 0;
 
-    if (!inp || !s2k)
+    if( !inp || !s2k )
         return CDK_Inv_Value;
 
-    if (DEBUG_PKT)
-        _cdk_log_debug ("** read S2K part\n");
+    if( DEBUG_PKT )
+        _cdk_log_debug( "** read S2K part\n" );
 
-    s2k->mode = stream_getc (inp);
-    if (s2k->mode == EOF || s2k->mode > 3)
+    s2k->mode = stream_getc( inp );
+    if( s2k->mode == EOF || s2k->mode > 3 )
         return CDK_Inv_Packet;
-    s2k->hash_algo = stream_getc (inp);
-    if (s2k->mode == 0)
-        ; /* nothing to do */
-    else if (s2k->mode == 1 || s2k->mode == 3) {
-        rc = stream_read (inp, s2k->salt, sizeof s2k->salt, &nread);
-        if (!rc && nread != sizeof s2k->salt)
+    s2k->hash_algo = stream_getc( inp );
+    if( s2k->mode == 0 ) {
+        memset( s2k->salt, 0, sizeof s2k->salt );
+        /* nothing else to do */
+    }
+    else if( s2k->mode == 1 || s2k->mode == 3 ) {
+        rc = stream_read( inp, s2k->salt, sizeof s2k->salt, &nread );
+        if( !rc && nread != sizeof s2k->salt )
             return CDK_Inv_Packet;
-        if (!rc && s2k->mode == 3) {
-            if ((s2k->count = stream_getc (inp)) == EOF)
+        if( !rc && s2k->mode == 3 ) {
+            s2k->count = stream_getc( inp );
+            if( s2k->count == EOF )
                 return CDK_Inv_Packet;
 	}
     }
@@ -238,42 +241,42 @@ read_encrypted (CDK_STREAM inp, size_t pktlen, cdkPKT_encrypted * enc,
 
 
 static int
-read_symkey_enc (CDK_STREAM inp, size_t pktlen, cdkPKT_symkey_enc * ske)
+read_symkey_enc( CDK_STREAM inp, size_t pktlen, cdkPKT_symkey_enc * ske )
 {
     CDK_S2K_HD s2k;
     size_t nread = 0, minlen = 0;
     int rc = 0;
 
-    if (!inp || !ske)
+    if( !inp || !ske )
         return CDK_Inv_Value;
 
-    if (DEBUG_PKT)
-        _cdk_log_debug ("** read symmetric key encrypted packet\n");
+    if( DEBUG_PKT )
+        _cdk_log_debug( "** read symmetric key encrypted packet\n" );
 
-    ske->version = stream_getc (inp);
-    if (ske->version != 4)
+    ske->version = stream_getc( inp );
+    if( ske->version != 4 )
         return CDK_Inv_Packet;
 
-    s2k = ske->s2k = cdk_calloc (1, sizeof *ske->s2k);
-    if (!ske->s2k)
+    s2k = ske->s2k = cdk_calloc( 1, sizeof *ske->s2k );
+    if( !ske->s2k )
         return CDK_Out_Of_Core;
   
-    ske->cipher_algo = stream_getc (inp);
-    s2k->mode = stream_getc (inp);
-    switch (s2k->mode) {
+    ske->cipher_algo = stream_getc( inp );
+    s2k->mode = stream_getc( inp );
+    switch( s2k->mode ) {
     case 0: minlen = 0; break;
     case 1: minlen = 8; break;
     case 3: minlen = 9; break;
     }
-    s2k->hash_algo = stream_getc (inp);
-    if (s2k->mode == 0)
+    s2k->hash_algo = stream_getc( inp );
+    if( s2k->mode == 0 )
         ; /* nothing to do */
-    if (s2k->mode == 1 || s2k->mode == 3) {
-        rc = stream_read (inp, s2k->salt, DIM (s2k->salt), &nread);
-        if (!rc && nread != DIM (s2k->salt))
+    else if( s2k->mode == 1 || s2k->mode == 3 ) {
+        rc = stream_read( inp, s2k->salt, DIM (s2k->salt), &nread);
+        if( !rc && nread != DIM( s2k->salt ) )
             return CDK_Inv_Packet;
-        if (!rc && s2k->mode == 3)
-            s2k->count = stream_getc (inp);
+        if( !rc && s2k->mode == 3 )
+            s2k->count = stream_getc( inp );
     }
     else
         return CDK_Inv_Packet;
