@@ -350,7 +350,7 @@ cdk_pk_check_sigs (CDK_KBNODE knode, CDK_KEYDB_HD hd, int * r_status)
                                 cdk_sig_get_keyid (sig, 0), cdk_strerror (rc));
 	    }
             else
-                _cdk_log_debug ("signature okay: signer %08X\n", sig->keyid[1]);
+                _cdk_log_debug ("signature OK: signer %08X\n", sig->keyid[1]);
 	}
     }
     if (!rc || rc == CDK_Error_No_Key)
