@@ -234,6 +234,7 @@ sig_write_old( CDK_KEYLIST list, CDK_STREAM inp, CDK_STREAM out,
  * @encryptflag: shall the output be encrypted? (1/0)
  * @sigmode: signature mode
  *
+ * Sign the data from the STREAM @inp.
  **/
 int
 cdk_stream_sign( CDK_HD hd, CDK_STREAM inp, CDK_STREAM out,
@@ -249,12 +250,14 @@ cdk_stream_sign( CDK_HD hd, CDK_STREAM inp, CDK_STREAM out,
     if( sigmode == CDK_SIGMODE_CLEAR )
         return stream_clearsign( hd, inp, out, locusr );
     
-    rc = cdk_sklist_build( hd->db.sec, locusr, &list, 1, GCRY_PK_USAGE_SIGN );
+    rc = cdk_sklist_build( hd->db.sec, hd, locusr, &list, 1, GCRY_PK_USAGE_SIGN );
     if( rc )
         return rc;
 
     sk = list->key.sk;
     digest_algo = _cdk_sig_hash_for( sk->pubkey_algo, sk->version );
+    if( cdk_handle_control( hd, CDK_CTLF_GET, CDK_CTL_FORCE_DIGEST ) )
+        digest_algo = hd->digest_algo;
 
     if( hd->opt.armor )
         cdk_stream_set_armor_flag( out, detached? 3 : 0 );
@@ -282,7 +285,7 @@ cdk_stream_sign( CDK_HD hd, CDK_STREAM inp, CDK_STREAM out,
             return rc;
         }
         if( !detached ) {
-            rc = cdk_sklist_write_onepass( list, out, 0x00 );
+            rc = cdk_sklist_write_onepass( list, out, 0x00, digest_algo );
             if( !rc )
                 rc = write_plaintext( inp, out );
         }
@@ -393,7 +396,7 @@ stream_clearsign( CDK_HD hd, CDK_STREAM inp, CDK_STREAM out,
     int digest_algo, sigver;
     int rc, nread;
     
-    rc = cdk_sklist_build( hd->db.sec, locusr, &list, 1, GCRY_PK_USAGE_SIGN );
+    rc = cdk_sklist_build( hd->db.sec, hd, locusr, &list, 1, GCRY_PK_USAGE_SIGN );
     if( rc )
         return rc;
 
