@@ -1,6 +1,6 @@
 /* -*- Mode: C; c-file-style: "bsd" -*- */
 /* trustdb.c - High level interface for ownertrust handling
- *        Copyright (C) 2001, 2002 Timo Schulz 
+ *        Copyright (C) 2001, 2002, 2003 Timo Schulz 
  *
  * This file is part of OpenCDK.
  *
@@ -37,8 +37,7 @@ enum {
     TDB_RECORD_VALID = 13,
 };
 
-typedef struct
-{
+typedef struct {
     int recno;
     union {
         struct {
@@ -59,66 +58,64 @@ typedef struct
 
 
 static void
-trustdb_rec_release (TRUSTREC rec)
+trustdb_rec_release( TRUSTREC rec )
 {
-    if (rec) {
+    if( rec ) {
         rec->recno = 0;
-        cdk_free (rec);
+        cdk_free( rec );
     }
 }
 
 
 static TRUSTREC
-trustdb_rec_new (void)
+trustdb_rec_new( void )
 {
     TRUSTREC rec;
 
-    rec = cdk_calloc (1, sizeof *rec);
-    if (!rec)
+    rec = cdk_calloc( 1, sizeof *rec );
+    if( !rec )
         return NULL;
-    rec->recno = 0;  
     return rec;
 }
 
 
 static int
-trustdb_check (CDK_STREAM a, int req_ver)
+trustdb_check( CDK_STREAM a, int req_ver )
 {
     int rc = 0;
     int c = 0, nread;
     byte magic[3];
 
-    cdk_stream_seek (a, 0);
-    c = cdk_stream_getc (a);
-    if (c == EOF || c != 1)
+    cdk_stream_seek( a, 0 );
+    c = cdk_stream_getc( a );
+    if( c == EOF || c != 1 )
         return CDK_General_Error;
-    nread = cdk_stream_read (a, magic, 3);
-    if (nread == EOF) {
-        rc = CDK_File_Error;
-        goto fail;
-    }
-    if ((c = cdk_stream_getc (a)) == EOF)
-        return CDK_General_Error;
-    if (c < req_ver)
-        return CDK_Wrong_Format;
- fail:
+    nread = cdk_stream_read( a, magic, 3 );
+    if( nread == EOF )
+        return CDK_File_Error;
+    c = cdk_stream_getc( a );
+    if( c == EOF )
+        rc = CDK_General_Error;
+    else if( c < req_ver )
+        rc = CDK_Wrong_Format;
     return rc;
 }
 
 
 static int
-trustdb_rec_parse (CDK_STREAM buf, TRUSTREC r)
+trustdb_rec_parse( CDK_STREAM buf, TRUSTREC r )
 {
     size_t n;
     int recno;
 
-    if (!buf || !r)
+    if( !buf || !r )
         return CDK_Inv_Value;
 
-    if ((recno = cdk_stream_getc (buf)) == EOF)
+    recno = cdk_stream_getc( buf );
+    if( recno == EOF )
         return EOF;
 
-    switch (recno) {
+    switch( recno ) {
     case TDB_RECORD_TRUST:	/* trust record: new */
         r->recno = 12;
         r->u.trust.reserved = cdk_stream_getc (buf);
@@ -159,13 +156,12 @@ trustdb_rec_parse (CDK_STREAM buf, TRUSTREC r)
         break;
     }
     r->recno = recno;
-
     return 0;
 }
 
 
 TRUSTREC
-trustdb_rec_byfpr (CDK_STREAM buf, int type, const byte * fpr, size_t fprlen)
+trustdb_rec_byfpr( CDK_STREAM buf, int type, const byte * fpr, size_t fprlen )
 {
     TRUSTREC rec;
 
@@ -173,100 +169,99 @@ trustdb_rec_byfpr (CDK_STREAM buf, int type, const byte * fpr, size_t fprlen)
         return NULL;
 
     rec = trustdb_rec_new ();
-    if (!rec)
+    if( !rec )
         return NULL;
 
-    while (trustdb_rec_parse (buf, rec) != EOF) {
-        if (rec->recno != type)
+    while( trustdb_rec_parse( buf, rec ) != EOF ) {
+        if( rec->recno != type )
             continue;
-        switch (type) {
+        switch( type ) {
 	case TDB_RECORD_VALID:
-            if (!memcmp (fpr, rec->u.valid.fpr, fprlen))
+            if( !memcmp( fpr, rec->u.valid.fpr, fprlen ) )
                 return rec;
             break;
 
 	case TDB_RECORD_TRUST:
-            if (!memcmp (rec->u.trust.fpr, fpr, fprlen))
+            if( !memcmp( rec->u.trust.fpr, fpr, fprlen ) )
                 return rec;
             break;
 	}
     }
-
-    trustdb_rec_release (rec);
-    return NULL;
+    trustdb_rec_release ( rec );
+    rec = NULL;
+    return rec;
 }
 
 
 int
-cdk_trustdb_get_ownertrust (CDK_STREAM inp, cdkPKT_public_key * pk,
-			    int *r_val, int *r_flags)
+cdk_trustdb_get_ownertrust( CDK_STREAM inp, cdkPKT_public_key * pk,
+			    int *r_val, int *r_flags )
 {
     TRUSTREC rec = NULL;
     byte fpr[20];
-    int rc = CDK_General_Error;
     int flags = 0;
+    int rc;
 
-    if (!inp || !r_val || !r_flags || !pk)
+    if( !inp || !r_val || !r_flags || !pk )
         return CDK_Inv_Value;
 
-    rc = trustdb_check (inp, MIN_TRUSTDB_VER);
-    if (rc)
+    rc = trustdb_check( inp, MIN_TRUSTDB_VER );
+    if( rc )
         return rc;
   
     *r_val = CDK_TRUST_UNKNOWN;
-    cdk_pk_get_fingerprint (pk, fpr);
-    cdk_stream_seek (inp, 0);
+    cdk_pk_get_fingerprint( pk, fpr );
+    cdk_stream_seek( inp, 0 );
 
-    rec = trustdb_rec_byfpr (inp, TDB_RECORD_TRUST, fpr, 20);
-    if (rec) {
+    rec = trustdb_rec_byfpr( inp, TDB_RECORD_TRUST, fpr, 20 );
+    if( rec ) {
         *r_val = rec->u.trust.ownertrust & TRUST_MASK;
-        if (*r_val & CDK_TFLAG_REVOKED)
+        if( *r_val & CDK_TFLAG_REVOKED )
             flags |= CDK_TFLAG_REVOKED;
-        if (*r_val & CDK_TFLAG_SUB_REVOKED)
+        if( *r_val & CDK_TFLAG_SUB_REVOKED )
             flags |= CDK_TFLAG_SUB_REVOKED;
-        if (*r_val & CDK_TFLAG_DISABLED)
+        if( *r_val & CDK_TFLAG_DISABLED )
             flags |= CDK_TFLAG_DISABLED;
         *r_flags = flags;
         rc = 0;
     }
-    trustdb_rec_release (rec);
+    trustdb_rec_release( rec );
     return rc;
 }
 
 
 int
-cdk_trustdb_get_validity (CDK_STREAM inp, cdkPKT_user_id * id, int *r_val)
+cdk_trustdb_get_validity( CDK_STREAM inp, cdkPKT_user_id * id, int *r_val )
 {
     GCRY_MD_HD rmd;
     TRUSTREC rec;
     byte * fpr;
-    int rc = CDK_General_Error;
+    int rc;
 
-    if (!inp || !r_val || !id)
+    if( !inp || !r_val || !id )
         return CDK_Inv_Value;
 
-    rc = trustdb_check (inp, MIN_TRUSTDB_VER);
-    if (rc)
+    rc = trustdb_check( inp, MIN_TRUSTDB_VER );
+    if( rc )
         return rc;
   
     *r_val = CDK_TRUST_UNKNOWN;
-    rmd = gcry_md_open (GCRY_MD_RMD160, 0);
-    if (!rmd)
+    rmd = gcry_md_open( GCRY_MD_RMD160, 0 );
+    if( !rmd )
         return CDK_Gcry_Error;
 
-    gcry_md_write (rmd, id->name, id->len);
-    gcry_md_final (rmd);
-    fpr = gcry_md_read (rmd, GCRY_MD_RMD160);
+    gcry_md_write( rmd, id->name, id->len );
+    gcry_md_final( rmd );
+    fpr = gcry_md_read( rmd, GCRY_MD_RMD160 );
 
-    cdk_stream_seek (inp, 0);
-    rec = trustdb_rec_byfpr (inp, TDB_RECORD_VALID, fpr, 20);
-    if (rec) {
+    cdk_stream_seek( inp, 0 );
+    rec = trustdb_rec_byfpr( inp, TDB_RECORD_VALID, fpr, 20 );
+    if( rec ) {
         *r_val = rec->u.valid.valid;
         rc = 0;
     }
-
-    trustdb_rec_release (rec);
-    gcry_md_close (rmd);
-
+    
+    trustdb_rec_release( rec );
+    gcry_md_close( rmd );
     return rc;
 }
