@@ -25,14 +25,13 @@
 #ifdef HAVE_CONFIG_H
 # include <config.h>
 #endif
-#ifdef HAVE_LIBPOPT
 #include <stdio.h>
 #include <popt.h>
-#include <opencdk.h>
 #include <string.h>
 #include <time.h>
 #include <stdlib.h>
 
+#include "opencdk.h"
 
 enum
 {
@@ -84,6 +83,7 @@ static struct
   {"MD5", CDK_MD_MD5},
   {"SHA1", CDK_MD_SHA1},
   {"RIPEMD160", CDK_MD_RMD160},
+  {"SHA256", CDK_MD_SHA256},
   {NULL},
 };
 
@@ -561,7 +561,7 @@ do_list_sigs (CDK_KEYDB_HD hd, CDK_STRLIST keys)
 
 
 char *
-get_passphrase (const char *prompt)
+get_passphrase (void * hd, const char *prompt)
 {
   char * p = NULL;
   int maxlen = 255;
@@ -844,9 +844,9 @@ main (int argc, char ** argv)
       return 0;
     }
   
-  /*cdk_passphrase_cb_set (get_passphrase);*/
 
   cdk_handle_new (&hd);
+  cdk_handle_set_passphrase_cb (hd, get_passphrase, NULL);
   cdk_handle_set_callback (hd, callback, NULL);
   cdk_handle_control (hd, CDK_CTLF_SET, CDK_CTL_OVERWRITE, 1);
   cdk_handle_control (hd, CDK_CTLF_SET, CDK_CTL_COMPRESS, 2, 5);
@@ -886,12 +886,12 @@ main (int argc, char ** argv)
           break;
 
 	case 'h':
-	  fprintf (stderr, "opencdk (MinPG) %s\n\n", VERSION);
+	  fprintf (stderr, "opencdk (MinPG) %s\n\n", OPENCDK_VERSION);
 	  poptPrintHelp (opt_ctx, stdout, 0);
 	  return 0;
 
 	case 'V':
-	  fprintf (stderr, "Minimal Privacy Guard (minpg) %s\n\n", VERSION);
+	  fprintf (stderr, "Minimal Privacy Guard (minpg) %s\n\n", OPENCDK_VERSION);
 	  fprintf (stderr, "Supported algorithms:\n");
 	  fprintf (stderr, "Cipher, Digest: ");
 	  for (i = 0; algo_table[i].name; i++)
@@ -986,6 +986,8 @@ main (int argc, char ** argv)
             {
               cdk_handle_control (hd, CDK_CTLF_SET, CDK_CTL_DIGEST,
                                   digest_algid);
+              if (!cipher_algid)
+                cipher_algid = CDK_CIPHER_3DES;
               cdk_handle_control (hd, CDK_CTLF_SET, CDK_CTL_S2K,
                                   3, digest_algid, cipher_algid);
             }
@@ -1062,6 +1064,11 @@ main (int argc, char ** argv)
           break;
           
         case 's':
+          cdk_handle_control (hd, CDK_CTLF_SET, CDK_CTL_FORCE_DIGEST, 1);
+          if (digest_algid)
+            cdk_handle_control (hd, CDK_CTLF_SET, CDK_CTL_DIGEST,digest_algid);
+          if (verbose)
+            fprintf (stdout, "force digest algo\n");
           if (!remusr)
             {
               fprintf (stdout, "No user was chosen.\n");
@@ -1144,11 +1151,3 @@ main (int argc, char ** argv)
   cdk_free (output);
   return 0;
 }
-#else
-int
-main (int argc, char ** argv)
-{
-  printf ("MinPG example is not available.\n");
-  return 0;
-}
-#endif /* HAVE_LIBPOPT */
